@@ -22,6 +22,7 @@ pub enum Mode {
     Move,
     Init,
     Dump,
+    Stats,
 }
 
 #[derive(Debug)]
@@ -63,7 +64,7 @@ pub enum HistoryFormat {
     Bash,
 
     /// zsh format - commands in plain text, with multiline commands on multiple lines.
-    /// McFly does not currently handle joining these lines; they're treated as separate commands.
+    /// `McFly` does not currently handle joining these lines; they're treated as separate commands.
     /// If --zsh-extended-history was given, `extended_history` will be true, and we'll strip the
     /// timestamp from the beginning of each command.
     Zsh { extended_history: bool },
@@ -151,6 +152,11 @@ pub struct Settings {
     pub pattern: Option<Regex>,
     pub dump_format: DumpFormat,
     pub colors: Colors,
+    pub stats_min_cmd_length: i16,
+    pub stats_cmds: i16,
+    pub stats_dirs: i16,
+    pub stats_global_commands_to_ignore: i16,
+    pub stats_only_dir: Option<String>,
 }
 
 impl Default for Settings {
@@ -211,6 +217,11 @@ impl Default for Settings {
                     results_selection_hl: Color::Grey,
                 },
             },
+            stats_min_cmd_length: 0,
+            stats_cmds: 10,
+            stats_dirs: 0,
+            stats_global_commands_to_ignore: 10,
+            stats_only_dir: None,
         }
     }
 }
@@ -261,8 +272,7 @@ impl Settings {
                 .unwrap_or_else(|err| {
                     if !settings.skip_environment_check {
                         panic!(
-                            "McFly error: Please ensure that MCFLY_SESSION_ID contains a random session ID ({})",
-                            err
+                            "McFly error: Please ensure that MCFLY_SESSION_ID contains a random session ID ({err})"
                         )
                     } else {
                         String::new()
@@ -275,10 +285,7 @@ impl Settings {
             {
                 env::var("MCFLY_HISTORY").unwrap_or_else(|err| {
                     if !settings.skip_environment_check {
-                        panic!(
-                            "McFly error: Please ensure that MCFLY_HISTORY is set ({})",
-                            err
-                        )
+                        panic!("McFly error: Please ensure that MCFLY_HISTORY is set ({err})")
                     } else {
                         String::new()
                     }
@@ -288,7 +295,7 @@ impl Settings {
         });
 
         {
-            use crate::cli::HistoryFormat::*;
+            use crate::cli::HistoryFormat::{Bash, Fish, Zsh, ZshExtended};
             settings.history_format = match cli.history_format {
                 Bash => HistoryFormat::Bash,
                 Zsh => HistoryFormat::Zsh {
@@ -317,7 +324,7 @@ impl Settings {
                         SystemTime::now()
                             .duration_since(UNIX_EPOCH)
                             .unwrap_or_else(|err| {
-                                panic!("McFly error: Time went backwards ({})", err)
+                                panic!("McFly error: Time went backwards ({err})")
                             })
                             .as_secs() as i64,
                     )
@@ -427,7 +434,7 @@ impl Settings {
             SubCommand::Init { shell } => {
                 settings.mode = Mode::Init;
 
-                use crate::cli::InitMode::*;
+                use crate::cli::InitMode::{Bash, Fish, Powershell, Zsh};
                 settings.init_mode = match shell {
                     Bash => InitMode::Bash,
                     Zsh => InitMode::Zsh,
@@ -451,6 +458,21 @@ impl Settings {
                 settings.pattern = regex;
                 settings.dump_format = format;
             }
+
+            SubCommand::Stats {
+                min_cmd_length,
+                cmds,
+                dirs,
+                global_commands_to_ignore,
+                only_dir,
+            } => {
+                settings.mode = Mode::Stats;
+                settings.stats_min_cmd_length = min_cmd_length;
+                settings.stats_cmds = cmds;
+                settings.stats_dirs = dirs;
+                settings.stats_global_commands_to_ignore = global_commands_to_ignore;
+                settings.stats_only_dir = only_dir;
+            }
         }
 
         settings.lightmode = is_env_var_truthy("MCFLY_LIGHT");
@@ -635,6 +657,7 @@ impl Settings {
     }
 
     // Use ~/.mcfly only if it already exists, otherwise create 'mcfly' folder in XDG_CACHE_DIR
+    #[must_use]
     pub fn mcfly_training_cache_path() -> PathBuf {
         let cache_dir = Settings::mcfly_xdg_dir().cache_dir().to_path_buf();
 
@@ -642,6 +665,7 @@ impl Settings {
     }
 
     // Use ~/.mcfly only if it already exists, otherwise create 'mcfly' folder in XDG_DATA_DIR
+    #[must_use]
     pub fn mcfly_db_path() -> PathBuf {
         let data_dir = Settings::mcfly_xdg_dir().data_dir().to_path_buf();
         if data_dir.exists() {
@@ -653,6 +677,7 @@ impl Settings {
     }
 
     // Use ~/.mcfly only if it already exists, otherwise create 'mcfly' folder in XDG_DATA_DIR
+    #[must_use]
     pub fn mcfly_config_path() -> PathBuf {
         let data_dir = Settings::mcfly_xdg_dir().data_dir().to_path_buf();
 
@@ -678,13 +703,10 @@ impl Settings {
 }
 
 #[cfg(not(windows))]
+#[must_use]
 pub fn pwd() -> String {
-    env::var("PWD").unwrap_or_else(|err| {
-        panic!(
-            "McFly error: Unable to determine current directory ({})",
-            err
-        )
-    })
+    env::var("PWD")
+        .unwrap_or_else(|err| panic!("McFly error: Unable to determine current directory ({err})"))
 }
 
 #[cfg(windows)]
@@ -717,6 +739,7 @@ fn is_env_var_truthy(name: &str) -> bool {
 impl TimeRange {
     /// Determine the range is full (`..`)
     #[inline]
+    #[must_use]
     pub fn is_full(&self) -> bool {
         self.since.is_none() && self.before.is_none()
     }
